Exception: Rodish::CommandExit

Inherits:
StandardError
  • Object
show all
Defined in:
lib/rodish/errors.rb

Overview

Rodish::CommandExit is the base error class for Rodish, signaling that a command execution finished. Callers of Rodish::Processor#process should rescue CommandExit to handle both failures as well as early exits.

Direct instances represent successful execution. This is raised when calling halt inside an options parser block (if an option should result in an early exit). It can also be raised manually inside command run blocks to exit early.

Direct Known Subclasses

CommandFailure

Instance Method Summary collapse

Instance Method Details

#failure?Boolean

Whether or not the command failed. For CommandExit, this always returns false, since CommandExit represents successful execution exits.

Returns:

  • (Boolean)


17
18
19
# File 'lib/rodish/errors.rb', line 17

def failure?
  false
end