Module: Rodish::Plugins::SkipOptionParsing::DSLMethods

Defined in:
lib/rodish/plugins/skip_option_parsing.rb

Instance Method Summary collapse

Instance Method Details

#skip_option_parsing(banner) ⇒ Object

Skip option parsing for the command. This is different then the default option parsing, which will error if any options are given. A banner must be provided, setting the usage for the command.

The main reason to use this is if you are going to pass the entire remaining argv as the argv to another program.



27
28
29
30
# File 'lib/rodish/plugins/skip_option_parsing.rb', line 27

def skip_option_parsing(banner)
  @command.banner = banner
  @command.option_parser = :skip
end